==> qt-creator-opensource-src-4.7.2.zip: qt-creator-opensource-src-4.7.2/src/tools/clangrefactoringbackend/source/collectmacrossourcefilecallbacks.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "collectmacrossourcefilecallbacks.h"
#include "collectmacrospreprocessorcallbacks.h"

#include <clang/Frontend/CompilerInstance.h>


namespace ClangBackEnd {

bool CollectMacrosSourceFileCallbacks::handleBeginSource(clang::CompilerInstance &compilerInstance)
{
    auto callbacks = std::make_unique<CollectMacrosPreprocessorCallbacks>(
                m_symbolEntries,
                m_sourceLocationEntries,
                m_sourceFiles,
                m_usedMacros,
                m_fileStatuses,
                m_sourceDependencies,
                m_filePathCache,
                compilerInstance.getSourceManager(),
                compilerInstance.getPreprocessorPtr());

    compilerInstance.getPreprocessorPtr()->addPPCallbacks(std::move(callbacks));

    return true;
}

} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.9.0.zip: qt-creator-opensource-src-4.9.0/src/tools/clangrefactoringbackend/source/collectmacrossourcefilecallbacks.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "collectmacrossourcefilecallbacks.h"
#include "collectmacrospreprocessorcallbacks.h"

#include <clang/Frontend/CompilerInstance.h>


namespace ClangBackEnd {

bool CollectMacrosSourceFileCallbacks::handleBeginSource(clang::CompilerInstance &compilerInstance)
{
    auto callbacks = std::make_unique<CollectMacrosPreprocessorCallbacks>(
                m_symbolEntries,
                m_sourceLocationEntries,
                m_sourceFiles,
                m_usedMacros,
                m_fileStatuses,
                m_sourceDependencies,
                m_filePathCache,
                compilerInstance.getSourceManager(),
                compilerInstance.getPreprocessorPtr(),
                m_sourcesManager);

    compilerInstance.getPreprocessorPtr()->addPPCallbacks(std::move(callbacks));

    return true;
}

} // namespace ClangBackEnd
